/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */
#ifndef __GdomRange_H__
#define __GdomRange_H__
#include <webkit/webkitdefines.h>
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomDocumentFragment.h"
#include "gdom/GdomNode.h"
#include "gdom/GdomRange.h"
#include "glib-object.h"


G_BEGIN_DECLS

typedef struct _GdomRange GdomRange;
typedef struct _GdomRangeClass GdomRangeClass;


#define GDOM_TYPE_RANGE            (gdom_range_get_type())
#define GDOM_RANGE(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), GDOM_TYPE_RANGE, GdomRange))
#define GDOM_RANGE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  GDOM_TYPE_RANGE, GdomRange)Class)
#define GDOM_IS_RANGE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), GDOM_TYPE_RANGE))
#define GDOM_IS_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  GDOM_TYPE_RANGE))
#define GDOM_RANGE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  GDOM_TYPE_RANGE, GdomRangeClass))

typedef struct _GdomRangePrivate GdomRangePrivate;

struct _GdomRange {
    GdomDOMObject parent_instance;
    GdomRangePrivate *priv;
};

struct _GdomRangeClass {
    GObjectClass parent_class;
};

WEBKIT_API GType
gdom_range_get_type (void);

WEBKIT_API void
gdom_range_set_start (GdomRange *thiz, GdomNode * ref_node, glong offset);

WEBKIT_API void
gdom_range_set_end (GdomRange *thiz, GdomNode * ref_node, glong offset);

WEBKIT_API void
gdom_range_set_start_before (GdomRange *thiz, GdomNode * ref_node);

WEBKIT_API void
gdom_range_set_start_after (GdomRange *thiz, GdomNode * ref_node);

WEBKIT_API void
gdom_range_set_end_before (GdomRange *thiz, GdomNode * ref_node);

WEBKIT_API void
gdom_range_set_end_after (GdomRange *thiz, GdomNode * ref_node);

WEBKIT_API void
gdom_range_collapse (GdomRange *thiz, gboolean to_start);

WEBKIT_API void
gdom_range_select_node (GdomRange *thiz, GdomNode * ref_node);

WEBKIT_API void
gdom_range_select_node_contents (GdomRange *thiz, GdomNode * ref_node);


/* XXX TODO: skipping CompareHow function gdom_range_compare_boundary_points */

WEBKIT_API void
gdom_range_delete_contents (GdomRange *thiz);

WEBKIT_API GdomDocumentFragment *
gdom_range_extract_contents (GdomRange *thiz);

WEBKIT_API GdomDocumentFragment *
gdom_range_clone_contents (GdomRange *thiz);

WEBKIT_API void
gdom_range_insert_node (GdomRange *thiz, GdomNode * new_node);

WEBKIT_API void
gdom_range_surround_contents (GdomRange *thiz, GdomNode * new_parent);

WEBKIT_API GdomRange *
gdom_range_clone_range (GdomRange *thiz);

WEBKIT_API gchar *
gdom_range_to_string (GdomRange *thiz);

WEBKIT_API void
gdom_range_detach (GdomRange *thiz);

WEBKIT_API GdomDocumentFragment *
gdom_range_create_contextual_fragment (GdomRange *thiz, gchar * html);

WEBKIT_API gboolean
gdom_range_intersects_node (GdomRange *thiz, GdomNode * ref_node);

WEBKIT_API gshort
gdom_range_compare_node (GdomRange *thiz, GdomNode * ref_node);

WEBKIT_API gshort
gdom_range_compare_point (GdomRange *thiz, GdomNode * ref_node, glong offset);

WEBKIT_API gboolean
gdom_range_is_point_in_range (GdomRange *thiz, GdomNode * ref_node, glong offset);

G_END_DECLS

#endif /* __GdomRange_H__ */
